Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
AlmondAddr string
AlmondUser string
AlmondPassword string
MQTTURL string
MQTTPrefix string
}
func (*Config) ApplyDefaults ¶
func (c *Config) ApplyDefaults()
type Lookup ¶
type Lookup struct {
// contains filtered or unexported fields
}
func (*Lookup) Device ¶
DeviceValue returns the device, index, kind and whether or not the device was found.
func (*Lookup) DeviceValue ¶
DeviceValue returns the device, index, kind and whether or not the device was found.
func (*Lookup) Update ¶
func (l *Lookup) Update(dl *marzipan.DeviceList)
Click to show internal directories.
Click to hide internal directories.